@@ -39,9 +39,7 @@ class __Config:
             return
         if not isinstance(value, (str, bool, int)):
             raise ValueError(
-                "Value must be instance of `str`, `bool` or `int`, but `{}` was used".format(
-                    type(value).__name__
-                )
+                "Value must be instance of `str`, `bool` or `int`, but `{}` was used".format(type(value).__name__)
             )
         self.__content[key] = value
 
@@ -56,9 +54,7 @@ class __Config:
         parsed = json_load(file)
         file.close()
         if not isinstance(parsed, Dict):
-            raise SyntaxError(
-                "Config file is in incorrect format.\n{}".format(str(filepath))
-            )
+            raise SyntaxError("Config file is in incorrect format.\n{}".format(str(filepath)))
         self.__content = parsed
         return True
 
@@ -144,9 +140,7 @@ class __Config:
         value = self._get_value(key)
         if value is None:
             if default is None:
-                raise ValueError(
-                    'Key "{}" not found and no default value informed'.format(key)
-                )
+                raise ValueError('Key "{}" not found and no default value informed'.format(key))
             return OS.machine_to_posix_path(default)
         if isinstance(value, str):
             return PurePosixPath(value)
@@ -155,5 +149,8 @@ class __Config:
     def put_path(self, key: str, value: PurePath) -> None:
         self._put_value(key, str(OS.machine_to_posix_path(value)))
 
+    def __repr__(self) -> str:
+        return "Config(" + self.__content.__repr__() + ")"
+
 
 Config = __Config()
